@@ -13,8 +13,9 @@
 ###
 
 setAs("Hits", "DataFrame", function(from) {
+  from_mcols <- mcols(from, use.names=FALSE)
   DataFrame(as.matrix(from),
-            if (!is.null(mcols(from))) mcols(from)
+            if (!is.null(from_mcols)) from_mcols
             else S4Vectors:::make_zero_col_DataFrame(length(from)))
 })
 
