@@ -26,6 +26,13 @@ setClass("RangedData", contains = c("DataTable", "List"),
          prototype = prototype(ranges = new("SimpleIRangesList"),
                                values = new("CompressedSplitDataFrameList")))
 
+RangedData_method_is_deprecated_msg <- function(what)
+  c("The ", what, " is deprecated ",
+    "and won't be replaced. Please migrate your code to use GRanges or ",
+    "GRangesList objects instead. RangedData objects will be deprecated ",
+    "soon (their use has been discouraged since BioC 2.12, that is, since ",
+    "2014). See IMPORTANT NOTE in ?RangedData")
+
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### Accessor methods.
 ###
@@ -112,7 +119,11 @@ setReplaceMethod("names", "RangedData",
 setMethod("elementNROWS", "RangedData", function(x) elementNROWS(ranges(x)))
 
 setMethod("space", "RangedData", function(x) space(ranges(x)))
+
+setGeneric("universe", function(x) standardGeneric("universe"))
 setMethod("universe", "RangedData", function(x) universe(ranges(x)))
+
+setGeneric("universe<-", function(x, value) standardGeneric("universe<-"))
 setReplaceMethod("universe", "RangedData",
                  function(x, value) {
                    universe(x@ranges) <- value
@@ -121,6 +132,8 @@ setReplaceMethod("universe", "RangedData",
 
 setMethod("score", "RangedData",
           function(x) {
+              what <- "score() getter for RangedData objects"
+              .Deprecated(msg=wmsg(RangedData_method_is_deprecated_msg(what)))
               score <- x[["score"]]
               ## if (is.null(score) && ncol(x) > 0 && is.numeric(x[[1L]]))
               ##     score <- x[[1L]]
@@ -129,6 +142,8 @@ setMethod("score", "RangedData",
 
 setReplaceMethod("score", "RangedData",
                  function(x, value) {
+                     what <- "score() setter for RangedData objects"
+                     .Deprecated(msg=wmsg(RangedData_method_is_deprecated_msg(what)))
                      if (!is.numeric(value))
                          stop("score must be numeric")
                      if (length(value) != nrow(x))
@@ -235,14 +250,9 @@ setValidity2("RangedData", .valid.RangedData)
 
 ## creates a single-element RangedData (unless splitter (space) is specified)
 
-RangedData <- function(ranges = IRanges(), ..., space = NULL, universe = NULL)
+RangedData <- function(ranges = IRanges(), ..., space = NULL)
 {
-  hasDots <- (((nargs() - !missing(space)) - !missing(universe)) > 1)
-  if (!is.null(universe)) {
-     msg <- wmsg("The 'universe' argument of the RangedData() ",
-                 "constructor function is defunct.")
-    .Defunct(msg=msg)
-  }
+  hasDots <- (((nargs() - !missing(space))) > 1)
   if (is(ranges, "IntegerRangesList") && !is(ranges, "IntegerRanges")) {
     if (!is.null(space))
       warning("since 'class(ranges)' extends IntegerRangesList, 'space' argument is ignored")
@@ -289,8 +299,6 @@ RangedData <- function(ranges = IRanges(), ..., space = NULL, universe = NULL)
         ranges <- as(ranges, "IRanges")
     ranges <- split(ranges, space)
   }
-  if (!is.null(universe))
-    universe(ranges) <- universe
 
   if (hasDots) {
     args <- list(...)
@@ -630,6 +638,8 @@ setAs("RangedData", "DataFrame",
 setAs("Rle", "RangedData",
       function(from)
       {
+        what <- "coercion method from Rle to RangedData"
+        .Deprecated(msg=wmsg(RangedData_method_is_deprecated_msg(what)))
         new2("RangedData",
              ranges = IRangesList("1" = successiveIRanges(runLength(from))),
              values =
@@ -641,6 +651,8 @@ setAs("Rle", "RangedData",
 setAs("RleList", "RangedData",
       function(from)
       {
+        what <- "coercion method from RleList to RangedData"
+        .Deprecated(msg=wmsg(RangedData_method_is_deprecated_msg(what)))
         ranges <-
           IRangesList(lapply(from, function(x)
                              successiveIRanges(runLength(x))))
@@ -655,11 +667,13 @@ setAs("RleList", "RangedData",
         new2("RangedData",
              ranges = ranges, values = values,
              metadata = metadata(from),
-             elementMetadata = elementMetadata(from),
+             elementMetadata = elementMetadata(from, use.names=FALSE),
              check = FALSE)
       })
 
 setAs("RleViewsList", "RangedData", function(from) {
+  what <- "coercion method from RleViewsList to RangedData"
+  .Deprecated(msg=wmsg(RangedData_method_is_deprecated_msg(what)))
   subject <- subject(from)
   from_ranges <- restrict(ranges(from), 1L, elementNROWS(subject),
                           keep.all.ranges = TRUE)
@@ -685,18 +699,22 @@ setAs("RleViewsList", "RangedData", function(from) {
 setAs("IntegerRanges", "RangedData",
       function(from)
       {
+        what <- "coercion method from IntegerRanges to RangedData"
+        .Deprecated(msg=wmsg(RangedData_method_is_deprecated_msg(what)))
         RangedData(from)
       })
 
 setAs("IntegerRangesList", "RangedData",
     function(from)
     {
+        what <- "coercion method from IntegerRangesList to RangedData"
+        .Deprecated(msg=wmsg(RangedData_method_is_deprecated_msg(what)))
         from_names <- names(from)
         if (is.null(from_names) || anyDuplicated(from_names))
             stop("cannot coerce a IntegerRangesList object with no names ",
                  "or duplicated names to a RangedData object")
         unlisted_from <- unlist(from, use.names=FALSE)
-        unlisted_values <- mcols(unlisted_from)
+        unlisted_values <- mcols(unlisted_from, use.names=FALSE)
         mcols(unlisted_from) <- NULL
         ans_ranges <- relist(unlisted_from, skeleton=from)
         metadata(ans_ranges) <- metadata(from)
@@ -716,12 +734,18 @@ setAs("IntegerRangesList", "RangedData",
              ranges=ans_ranges,
              values=ans_values,
              #metadata=metadata(from),
-             elementMetadata=elementMetadata(from),
+             elementMetadata=elementMetadata(from, use.names=FALSE),
              check=FALSE)
     }
 )
 
-setAs("list", "RangedData", function(from) do.call(c, unname(from)))
+setAs("list", "RangedData",
+  function(from) {
+    what <- "coercion method from list to RangedData"
+    .Deprecated(msg=wmsg(RangedData_method_is_deprecated_msg(what)))
+    do.call(c, unname(from))
+  }
+)
 
 .fromRangedDataToCompressedIRangesList <- function(from)
 {
@@ -738,7 +762,7 @@ setAs("RangedData", "CompressedIRangesList",
 setAs("RangedData", "IRangesList", .fromRangedDataToCompressedIRangesList)
 
 setMethod("as.env", "RangedData", function(x, enclos = parent.frame(2)) {
-  env <- callNextMethod(x, enclos)
+  env <- S4Vectors:::makeEnvForNames(x, colnames(x), enclos)
   makeAccessorBinding <- function(fun, name = deparse(substitute(fun))) {
     makeActiveBinding(name, function() {
       val <- fun(x)
@@ -756,6 +780,8 @@ setMethod("as.env", "RangedData", function(x, enclos = parent.frame(2)) {
 })
 
 .RangedData_fromDataFrame <- function(from) {
+  what <- "coercion method from data.frame or DataTable to RangedData"
+  .Deprecated(msg=wmsg(RangedData_method_is_deprecated_msg(what)))
   required <- c("start", "end")
   if (!all(required %in% colnames(from)))
     stop("'from' must at least include a 'start' and 'end' column")
