@@ -9,6 +9,8 @@
 setMethod("lapply", "RangedData",
           function(X, FUN, ...)
           {
+            what <- "\"lapply\" method for RangedData objects"
+            .Deprecated(msg=wmsg(RangedData_method_is_deprecated_msg(what)))
             FUN <- match.fun(FUN)
             inds <- structure(seq(length(X)), names = names(X))
             lapply(inds, function(i) FUN(X[i], ...))
@@ -21,6 +23,8 @@ setMethod("lapply", "RangedData",
 setMethod("within", "RangedData",
           function(data, expr, ...)
           {
+            what <- "\"within\" method for RangedData objects"
+            .Deprecated(msg=wmsg(RangedData_method_is_deprecated_msg(what)))
             e <- list2env(as.list(as(data, "DataFrame")))
             e$ranges <- ranges(data)
             S4Vectors:::safeEval(substitute(expr), e, S4Vectors:::top_prenv(expr))
@@ -45,14 +49,3 @@ setMethod("within", "RangedData",
             data
           })
 
-### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### Merging (TODO)
-###
-
-#setMethod("merge", "RangedData",
-#          function(x, y, by = 1, all = FALSE, all.x = all, all.y = all,
-#                   resolver = intersect, sort = TRUE, suffixes = c(".x",".y"))
-#          {
-#            
-#          })
-
